Feedforward Closedloop Learning: Member List

Feedforward Closedloop Learning

Bandpass Member List

This is the complete list of members for Bandpass, including all inherited members.

Bandpass() | Bandpass |
calcNorm(double f) | Bandpass |
calcPolesZeros(double f, double r) | Bandpass |
filter(double v) | Bandpass |
getOutput() | Bandpass | inline
impulse(char *name) | Bandpass |
reset() | Bandpass |
setParameters(double frequency, double Qfactor) | Bandpass |
transfer(char *name) | Bandpass |